/********************************************************************************
** Form generated from reading UI file 'conf_ui2.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONF_UI2_H
#define UI_CONF_UI2_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcolorbutton.h"

QT_BEGIN_NAMESPACE

class Ui_UIConf
{
public:
    QGridLayout *gridLayout;
    QTabWidget *tabWidget3;
    QWidget *tab;
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    QVBoxLayout *vboxLayout1;
    QLabel *textLabel_trustUltimate;
    QLabel *textLabel_trustTrusted;
    QLabel *textLabel_trustMarginally;
    QLabel *textLabel_trustExpired;
    QLabel *textLabel_trustRevoked;
    QLabel *textLabel_trustUnknown;
    QLabel *textLabel_trustDisabled;
    QVBoxLayout *vboxLayout2;
    KColorButton *kcfg_ColorUltimate;
    KColorButton *kcfg_ColorGood;
    KColorButton *kcfg_ColorMarginal;
    KColorButton *kcfg_ColorExpired;
    KColorButton *kcfg_ColorRev;
    KColorButton *kcfg_ColorUnknown;
    KColorButton *kcfg_ColorBad;
    QSpacerItem *spacerItem;
    QWidget *TabPage;
    QWidget *tabKeyList;
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBoxSorting;
    QFormLayout *formLayout;
    QLabel *label_EmailSorting;
    QComboBox *kcfg_EmailSorting;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *UIConf)
    {
        if (UIConf->objectName().isEmpty())
            UIConf->setObjectName("UIConf");
        UIConf->resize(833, 472);
        gridLayout = new QGridLayout(UIConf);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        tabWidget3 = new QTabWidget(UIConf);
        tabWidget3->setObjectName("tabWidget3");
        tab = new QWidget();
        tab->setObjectName("tab");
        vboxLayout = new QVBoxLayout(tab);
        vboxLayout->setObjectName("vboxLayout");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setObjectName("vboxLayout1");
        textLabel_trustUltimate = new QLabel(tab);
        textLabel_trustUltimate->setObjectName("textLabel_trustUltimate");
        textLabel_trustUltimate->setWordWrap(false);

        vboxLayout1->addWidget(textLabel_trustUltimate);

        textLabel_trustTrusted = new QLabel(tab);
        textLabel_trustTrusted->setObjectName("textLabel_trustTrusted");
        textLabel_trustTrusted->setWordWrap(false);

        vboxLayout1->addWidget(textLabel_trustTrusted);

        textLabel_trustMarginally = new QLabel(tab);
        textLabel_trustMarginally->setObjectName("textLabel_trustMarginally");
        textLabel_trustMarginally->setWordWrap(false);

        vboxLayout1->addWidget(textLabel_trustMarginally);

        textLabel_trustExpired = new QLabel(tab);
        textLabel_trustExpired->setObjectName("textLabel_trustExpired");
        textLabel_trustExpired->setWordWrap(false);

        vboxLayout1->addWidget(textLabel_trustExpired);

        textLabel_trustRevoked = new QLabel(tab);
        textLabel_trustRevoked->setObjectName("textLabel_trustRevoked");
        textLabel_trustRevoked->setWordWrap(false);

        vboxLayout1->addWidget(textLabel_trustRevoked);

        textLabel_trustUnknown = new QLabel(tab);
        textLabel_trustUnknown->setObjectName("textLabel_trustUnknown");
        textLabel_trustUnknown->setWordWrap(false);

        vboxLayout1->addWidget(textLabel_trustUnknown);

        textLabel_trustDisabled = new QLabel(tab);
        textLabel_trustDisabled->setObjectName("textLabel_trustDisabled");
        textLabel_trustDisabled->setWordWrap(false);

        vboxLayout1->addWidget(textLabel_trustDisabled);


        hboxLayout->addLayout(vboxLayout1);

        vboxLayout2 = new QVBoxLayout();
        vboxLayout2->setObjectName("vboxLayout2");
        kcfg_ColorUltimate = new KColorButton(tab);
        kcfg_ColorUltimate->setObjectName("kcfg_ColorUltimate");
        kcfg_ColorUltimate->setColor(QColor(68, 0, 255));

        vboxLayout2->addWidget(kcfg_ColorUltimate);

        kcfg_ColorGood = new KColorButton(tab);
        kcfg_ColorGood->setObjectName("kcfg_ColorGood");
        kcfg_ColorGood->setColor(QColor(144, 255, 0));

        vboxLayout2->addWidget(kcfg_ColorGood);

        kcfg_ColorMarginal = new KColorButton(tab);
        kcfg_ColorMarginal->setObjectName("kcfg_ColorMarginal");
        kcfg_ColorMarginal->setColor(QColor(255, 255, 0));

        vboxLayout2->addWidget(kcfg_ColorMarginal);

        kcfg_ColorExpired = new KColorButton(tab);
        kcfg_ColorExpired->setObjectName("kcfg_ColorExpired");
        kcfg_ColorExpired->setColor(QColor(150, 150, 150));

        vboxLayout2->addWidget(kcfg_ColorExpired);

        kcfg_ColorRev = new KColorButton(tab);
        kcfg_ColorRev->setObjectName("kcfg_ColorRev");
        kcfg_ColorRev->setColor(QColor(30, 30, 30));

        vboxLayout2->addWidget(kcfg_ColorRev);

        kcfg_ColorUnknown = new KColorButton(tab);
        kcfg_ColorUnknown->setObjectName("kcfg_ColorUnknown");

        vboxLayout2->addWidget(kcfg_ColorUnknown);

        kcfg_ColorBad = new KColorButton(tab);
        kcfg_ColorBad->setObjectName("kcfg_ColorBad");
        kcfg_ColorBad->setColor(QColor(172, 0, 0));

        vboxLayout2->addWidget(kcfg_ColorBad);


        hboxLayout->addLayout(vboxLayout2);


        vboxLayout->addLayout(hboxLayout);

        spacerItem = new QSpacerItem(402, 121, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem);

        tabWidget3->addTab(tab, QString());
        TabPage = new QWidget();
        TabPage->setObjectName("TabPage");
        tabWidget3->addTab(TabPage, QString());
        tabKeyList = new QWidget();
        tabKeyList->setObjectName("tabKeyList");
        verticalLayout = new QVBoxLayout(tabKeyList);
        verticalLayout->setObjectName("verticalLayout");
        groupBoxSorting = new QGroupBox(tabKeyList);
        groupBoxSorting->setObjectName("groupBoxSorting");
        formLayout = new QFormLayout(groupBoxSorting);
        formLayout->setObjectName("formLayout");
        label_EmailSorting = new QLabel(groupBoxSorting);
        label_EmailSorting->setObjectName("label_EmailSorting");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_EmailSorting);

        kcfg_EmailSorting = new QComboBox(groupBoxSorting);
        kcfg_EmailSorting->addItem(QString());
        kcfg_EmailSorting->addItem(QString());
        kcfg_EmailSorting->addItem(QString());
        kcfg_EmailSorting->addItem(QString());
        kcfg_EmailSorting->setObjectName("kcfg_EmailSorting");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_EmailSorting);


        verticalLayout->addWidget(groupBoxSorting);

        verticalSpacer = new QSpacerItem(20, 351, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        tabWidget3->addTab(tabKeyList, QString());

        gridLayout->addWidget(tabWidget3, 0, 0, 1, 1);

#if QT_CONFIG(shortcut)
        label_EmailSorting->setBuddy(kcfg_EmailSorting);
#endif // QT_CONFIG(shortcut)

        retranslateUi(UIConf);

        tabWidget3->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(UIConf);
    } // setupUi

    void retranslateUi(QWidget *UIConf)
    {
        textLabel_trustUltimate->setText(tr2i18n("Ultimately trusted keys:", nullptr));
        textLabel_trustTrusted->setText(tr2i18n("Trusted keys:", nullptr));
        textLabel_trustMarginally->setText(tr2i18n("Marginally trusted keys:", nullptr));
        textLabel_trustExpired->setText(tr2i18n("Expired keys:", nullptr));
        textLabel_trustRevoked->setText(tr2i18n("Revoked keys:", nullptr));
        textLabel_trustUnknown->setText(tr2i18n("Unknown keys:", nullptr));
        textLabel_trustDisabled->setText(tr2i18n("Disabled keys:", nullptr));
        kcfg_ColorUltimate->setText(QString());
        kcfg_ColorGood->setText(QString());
        kcfg_ColorMarginal->setText(QString());
        kcfg_ColorExpired->setText(QString());
        kcfg_ColorRev->setText(QString());
        kcfg_ColorUnknown->setText(QString());
        kcfg_ColorBad->setText(QString());
        tabWidget3->setTabText(tabWidget3->indexOf(tab), tr2i18n("Key Colors", nullptr));
        tabWidget3->setTabText(tabWidget3->indexOf(TabPage), tr2i18n("Editor Font", nullptr));
        groupBoxSorting->setTitle(tr2i18n("Sort Order", nullptr));
        label_EmailSorting->setText(tr2i18n("Email:", nullptr));
        kcfg_EmailSorting->setItemText(0, tr2i18n("Left to right, account first", nullptr));
        kcfg_EmailSorting->setItemText(1, tr2i18n("Right to left, TLD first", nullptr));
        kcfg_EmailSorting->setItemText(2, tr2i18n("Right to left, domain first", nullptr));
        kcfg_EmailSorting->setItemText(3, tr2i18n("Right to left, FQDN first", nullptr));

        tabWidget3->setTabText(tabWidget3->indexOf(tabKeyList), tr2i18n("Key List", nullptr));
        (void)UIConf;
    } // retranslateUi

};

namespace Ui {
    class UIConf: public Ui_UIConf {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONF_UI2_H

