/********************************************************************************
** Form generated from reading UI file 'conf_servers.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONF_SERVERS_H
#define UI_CONF_SERVERS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ServerConf
{
public:
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    QVBoxLayout *vboxLayout1;
    QListView *ServerBox;
    QLabel *textLabel1_4;
    QCheckBox *kcfg_UseProxy;
    QVBoxLayout *vboxLayout2;
    QPushButton *server_default;
    QPushButton *server_add;
    QPushButton *server_del;
    QPushButton *server_edit;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *ServerConf)
    {
        if (ServerConf->objectName().isEmpty())
            ServerConf->setObjectName("ServerConf");
        ServerConf->resize(642, 294);
        vboxLayout = new QVBoxLayout(ServerConf);
        vboxLayout->setObjectName("vboxLayout");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setObjectName("vboxLayout1");
        ServerBox = new QListView(ServerConf);
        ServerBox->setObjectName("ServerBox");

        vboxLayout1->addWidget(ServerBox);

        textLabel1_4 = new QLabel(ServerConf);
        textLabel1_4->setObjectName("textLabel1_4");
        textLabel1_4->setWordWrap(true);

        vboxLayout1->addWidget(textLabel1_4);

        kcfg_UseProxy = new QCheckBox(ServerConf);
        kcfg_UseProxy->setObjectName("kcfg_UseProxy");

        vboxLayout1->addWidget(kcfg_UseProxy);


        hboxLayout->addLayout(vboxLayout1);

        vboxLayout2 = new QVBoxLayout();
        vboxLayout2->setObjectName("vboxLayout2");
        server_default = new QPushButton(ServerConf);
        server_default->setObjectName("server_default");
        server_default->setEnabled(false);

        vboxLayout2->addWidget(server_default);

        server_add = new QPushButton(ServerConf);
        server_add->setObjectName("server_add");

        vboxLayout2->addWidget(server_add);

        server_del = new QPushButton(ServerConf);
        server_del->setObjectName("server_del");
        server_del->setEnabled(false);

        vboxLayout2->addWidget(server_del);

        server_edit = new QPushButton(ServerConf);
        server_edit->setObjectName("server_edit");

        vboxLayout2->addWidget(server_edit);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout2->addItem(spacerItem);


        hboxLayout->addLayout(vboxLayout2);


        vboxLayout->addLayout(hboxLayout);


        retranslateUi(ServerConf);

        QMetaObject::connectSlotsByName(ServerConf);
    } // setupUi

    void retranslateUi(QWidget *ServerConf)
    {
        textLabel1_4->setText(tr2i18n("<b>INFORMATION</b>:\n"
"Only the default server will be stored in GnuPG's configuration file,\n"
"all others will be stored for use by KGpg only.", nullptr));
        kcfg_UseProxy->setText(tr2i18n("Honor HTTP proxy when available", nullptr));
        server_default->setText(tr2i18n("&Set as Default", nullptr));
        server_add->setText(tr2i18n("&Add...", nullptr));
        server_del->setText(tr2i18n("&Delete", nullptr));
        server_edit->setText(tr2i18n("&Edit...", nullptr));
        (void)ServerConf;
    } // retranslateUi

};

namespace Ui {
    class ServerConf: public Ui_ServerConf {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONF_SERVERS_H

