/********************************************************************************
** Form generated from reading UI file 'searchres.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SEARCHRES_H
#define UI_SEARCHRES_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_searchRes
{
public:
    QVBoxLayout *vboxLayout;
    QLabel *statusText;
    QHBoxLayout *hboxLayout;
    QLabel *filterEditLabel;
    QLineEdit *filterEdit;
    QCheckBox *validFilterCheckbox;
    QTreeView *kLVsearch;
    QHBoxLayout *hboxLayout1;
    QLabel *textLabel1;
    QLineEdit *qLEID;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *searchRes)
    {
        if (searchRes->objectName().isEmpty())
            searchRes->setObjectName("searchRes");
        searchRes->resize(446, 262);
        vboxLayout = new QVBoxLayout(searchRes);
        vboxLayout->setObjectName("vboxLayout");
        statusText = new QLabel(searchRes);
        statusText->setObjectName("statusText");
        statusText->setWordWrap(false);

        vboxLayout->addWidget(statusText);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        filterEditLabel = new QLabel(searchRes);
        filterEditLabel->setObjectName("filterEditLabel");
        filterEditLabel->setWordWrap(true);

        hboxLayout->addWidget(filterEditLabel);

        filterEdit = new QLineEdit(searchRes);
        filterEdit->setObjectName("filterEdit");
        filterEdit->setClearButtonEnabled(true);

        hboxLayout->addWidget(filterEdit);


        vboxLayout->addLayout(hboxLayout);

        validFilterCheckbox = new QCheckBox(searchRes);
        validFilterCheckbox->setObjectName("validFilterCheckbox");
        validFilterCheckbox->setChecked(true);

        vboxLayout->addWidget(validFilterCheckbox);

        kLVsearch = new QTreeView(searchRes);
        kLVsearch->setObjectName("kLVsearch");
        kLVsearch->setRootIsDecorated(true);
        kLVsearch->setSortingEnabled(true);
        kLVsearch->setAllColumnsShowFocus(true);

        vboxLayout->addWidget(kLVsearch);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        textLabel1 = new QLabel(searchRes);
        textLabel1->setObjectName("textLabel1");
        textLabel1->setWordWrap(false);

        hboxLayout1->addWidget(textLabel1);

        qLEID = new QLineEdit(searchRes);
        qLEID->setObjectName("qLEID");
        qLEID->setClearButtonEnabled(true);

        hboxLayout1->addWidget(qLEID);


        vboxLayout->addLayout(hboxLayout1);

        buttonBox = new QDialogButtonBox(searchRes);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Close|QDialogButtonBox::Ok);

        vboxLayout->addWidget(buttonBox);

        QWidget::setTabOrder(kLVsearch, qLEID);

        retranslateUi(searchRes);

        QMetaObject::connectSlotsByName(searchRes);
    } // setupUi

    void retranslateUi(QWidget *searchRes)
    {
        statusText->setText(QString());
        filterEditLabel->setText(tr2i18n("Search:", nullptr));
        validFilterCheckbox->setText(tr2i18n("Show only valid keys", nullptr));
        textLabel1->setText(tr2i18n("Key to import:", nullptr));
        (void)searchRes;
    } // retranslateUi

};

namespace Ui {
    class searchRes: public Ui_searchRes {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SEARCHRES_H

