/****************************************************************************
** Meta object code from reading C++ file 'kgpgeditor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../kgpg-26.07.80/editor/kgpgeditor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kgpgeditor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10KgpgEditorE_t {};
} // unnamed namespace

template <> constexpr inline auto KgpgEditor::qt_create_metaobjectdata<qt_meta_tag_ZN10KgpgEditorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KgpgEditor",
        "openChangeFont",
        "",
        "openConfigDialog",
        "openDocumentFile",
        "QUrl",
        "url",
        "encoding",
        "slotSetFont",
        "QFont",
        "myFont",
        "closeWindow",
        "slotFileNew",
        "slotFileOpen",
        "slotFileSave",
        "slotFileSaveAs",
        "slotFilePrint",
        "slotFilePreEnc",
        "slotFilePreDec",
        "slotKeyManager",
        "slotFileClose",
        "slotundo",
        "slotredo",
        "slotEditCut",
        "slotEditCopy",
        "slotEditPaste",
        "slotSelectAll",
        "slotFind",
        "slotFindNext",
        "slotFindPrev",
        "slotFindText",
        "slotSetCharset",
        "slotResetEncoding",
        "enc",
        "slotPreSignFile",
        "slotSignFile",
        "slotSignFileFin",
        "slotPreVerifyFile",
        "slotVerifyFile",
        "slotCheckMd5",
        "importSignatureKey",
        "id",
        "fileName",
        "slotOptions",
        "slotUndoAvailable",
        "v",
        "slotRedoAvailable",
        "slotCopyAvailable",
        "modified",
        "newText",
        "slotLibraryDone",
        "slotDownloadKeysFinished",
        "ids"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'openChangeFont'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openConfigDialog'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'openDocumentFile'
        QtMocHelpers::SlotData<void(const QUrl &, const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { QMetaType::QString, 7 },
        }}),
        // Slot 'openDocumentFile'
        QtMocHelpers::SlotData<void(const QUrl &)>(4, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'slotSetFont'
        QtMocHelpers::SlotData<void(QFont)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'closeWindow'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFileNew'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotFileOpen'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotFileSave'
        QtMocHelpers::SlotData<bool()>(14, 2, QMC::AccessPrivate, QMetaType::Bool),
        // Slot 'slotFileSaveAs'
        QtMocHelpers::SlotData<bool()>(15, 2, QMC::AccessPrivate, QMetaType::Bool),
        // Slot 'slotFilePrint'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotFilePreEnc'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotFilePreDec'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotKeyManager'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotFileClose'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotundo'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotredo'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEditCut'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEditCopy'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEditPaste'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSelectAll'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotFind'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotFindNext'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotFindPrev'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotFindText'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSetCharset'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotResetEncoding'
        QtMocHelpers::SlotData<void(bool)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 33 },
        }}),
        // Slot 'slotPreSignFile'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSignFile'
        QtMocHelpers::SlotData<void(const QUrl &)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'slotSignFileFin'
        QtMocHelpers::SlotData<void(int)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotPreVerifyFile'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotVerifyFile'
        QtMocHelpers::SlotData<void(const QUrl &)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'slotCheckMd5'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'importSignatureKey'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 41 }, { QMetaType::QString, 42 },
        }}),
        // Slot 'slotOptions'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUndoAvailable'
        QtMocHelpers::SlotData<void(const bool)>(44, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 45 },
        }}),
        // Slot 'slotRedoAvailable'
        QtMocHelpers::SlotData<void(const bool)>(46, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 45 },
        }}),
        // Slot 'slotCopyAvailable'
        QtMocHelpers::SlotData<void(const bool)>(47, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 45 },
        }}),
        // Slot 'modified'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'newText'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotLibraryDone'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDownloadKeysFinished'
        QtMocHelpers::SlotData<void(const QStringList &)>(51, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QStringList, 52 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KgpgEditor, qt_meta_tag_ZN10KgpgEditorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KgpgEditor::staticMetaObject = { {
    QMetaObject::SuperData::link<KXmlGuiWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KgpgEditorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KgpgEditorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10KgpgEditorE_t>.metaTypes,
    nullptr
} };

void KgpgEditor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KgpgEditor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->openChangeFont(); break;
        case 1: _t->openConfigDialog(); break;
        case 2: _t->openDocumentFile((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->openDocumentFile((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 4: _t->slotSetFont((*reinterpret_cast<std::add_pointer_t<QFont>>(_a[1]))); break;
        case 5: _t->closeWindow(); break;
        case 6: _t->slotFileNew(); break;
        case 7: _t->slotFileOpen(); break;
        case 8: { bool _r = _t->slotFileSave();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->slotFileSaveAs();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->slotFilePrint(); break;
        case 11: _t->slotFilePreEnc(); break;
        case 12: _t->slotFilePreDec(); break;
        case 13: _t->slotKeyManager(); break;
        case 14: _t->slotFileClose(); break;
        case 15: _t->slotundo(); break;
        case 16: _t->slotredo(); break;
        case 17: _t->slotEditCut(); break;
        case 18: _t->slotEditCopy(); break;
        case 19: _t->slotEditPaste(); break;
        case 20: _t->slotSelectAll(); break;
        case 21: _t->slotFind(); break;
        case 22: _t->slotFindNext(); break;
        case 23: _t->slotFindPrev(); break;
        case 24: _t->slotFindText(); break;
        case 25: _t->slotSetCharset(); break;
        case 26: _t->slotResetEncoding((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 27: _t->slotPreSignFile(); break;
        case 28: _t->slotSignFile((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 29: _t->slotSignFileFin((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 30: _t->slotPreVerifyFile(); break;
        case 31: _t->slotVerifyFile((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 32: _t->slotCheckMd5(); break;
        case 33: _t->importSignatureKey((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 34: _t->slotOptions(); break;
        case 35: _t->slotUndoAvailable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 36: _t->slotRedoAvailable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 37: _t->slotCopyAvailable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 38: _t->modified(); break;
        case 39: _t->newText(); break;
        case 40: _t->slotLibraryDone(); break;
        case 41: _t->slotDownloadKeysFinished((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KgpgEditor::*)()>(_a, &KgpgEditor::openChangeFont, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KgpgEditor::*)()>(_a, &KgpgEditor::openConfigDialog, 1))
            return;
    }
}

const QMetaObject *KgpgEditor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KgpgEditor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KgpgEditorE_t>.strings))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int KgpgEditor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 42)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 42;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 42)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 42;
    }
    return _id;
}

// SIGNAL 0
void KgpgEditor::openChangeFont()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KgpgEditor::openConfigDialog()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
