/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kgpg.Key.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef KEYADAPTOR_H
#define KEYADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "keysmanager.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.kgpg.Key
 */
class KeyAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.kgpg.Key")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.kgpg.Key\">\n"
"    <method name=\"showKeyInfo\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"keyID\"/>\n"
"    </method>\n"
"    <method name=\"importRemoteKey\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"keyID\"/>\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"showOptions\"/>\n"
"    <method name=\"showKeyServer\"/>\n"
"    <method name=\"showKeyManager\"/>\n"
"  </interface>\n"
        "")
public:
    KeyAdaptor(KeysManager *parent);
    ~KeyAdaptor() override;

    inline KeysManager *parent() const
    { return static_cast<KeysManager *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    bool importRemoteKey(const QString &keyID);
    void showKeyInfo(const QString &keyID);
    void showKeyManager();
    void showKeyServer();
    void showOptions();
Q_SIGNALS: // SIGNALS
};

#endif
