/********************************************************************************
** Form generated from reading UI file 'adduid.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ADDUID_H
#define UI_ADDUID_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_AddUid
{
public:
    QVBoxLayout *vboxLayout;
    QLabel *textLabel1;
    QLineEdit *qLineEdit1;
    QLabel *textLabel2;
    QLineEdit *qLineEdit2;
    QLabel *textLabel3;
    QLineEdit *qLineEdit3;
    QSpacerItem *spacerItem;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *AddUid)
    {
        if (AddUid->objectName().isEmpty())
            AddUid->setObjectName("AddUid");
        AddUid->resize(408, 283);
        vboxLayout = new QVBoxLayout(AddUid);
        vboxLayout->setObjectName("vboxLayout");
        textLabel1 = new QLabel(AddUid);
        textLabel1->setObjectName("textLabel1");
        textLabel1->setWordWrap(false);

        vboxLayout->addWidget(textLabel1);

        qLineEdit1 = new QLineEdit(AddUid);
        qLineEdit1->setObjectName("qLineEdit1");

        vboxLayout->addWidget(qLineEdit1);

        textLabel2 = new QLabel(AddUid);
        textLabel2->setObjectName("textLabel2");
        textLabel2->setWordWrap(false);

        vboxLayout->addWidget(textLabel2);

        qLineEdit2 = new QLineEdit(AddUid);
        qLineEdit2->setObjectName("qLineEdit2");

        vboxLayout->addWidget(qLineEdit2);

        textLabel3 = new QLabel(AddUid);
        textLabel3->setObjectName("textLabel3");
        textLabel3->setWordWrap(false);

        vboxLayout->addWidget(textLabel3);

        qLineEdit3 = new QLineEdit(AddUid);
        qLineEdit3->setObjectName("qLineEdit3");

        vboxLayout->addWidget(qLineEdit3);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem);

        buttonBox = new QDialogButtonBox(AddUid);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        vboxLayout->addWidget(buttonBox);


        retranslateUi(AddUid);

        QMetaObject::connectSlotsByName(AddUid);
    } // setupUi

    void retranslateUi(QWidget *AddUid)
    {
        textLabel1->setText(tr2i18n("Name (minimum 5 characters):", nullptr));
        textLabel2->setText(tr2i18n("Email:", nullptr));
        textLabel3->setText(tr2i18n("Comment (optional):", nullptr));
        (void)AddUid;
    } // retranslateUi

};

namespace Ui {
    class AddUid: public Ui_AddUid {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ADDUID_H

