/****************************************************************************
** Meta object code from reading C++ file 'kgpgoptions.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../kgpg-26.07.80/kgpgoptions.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kgpgoptions.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11kgpgOptionsE_t {};
} // unnamed namespace

template <> constexpr inline auto kgpgOptions::qt_create_metaobjectdata<qt_meta_tag_ZN11kgpgOptionsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "kgpgOptions",
        "updateDisplay",
        "",
        "settingsUpdated",
        "changeFont",
        "QFont",
        "homeChanged",
        "refreshTrust",
        "KgpgCore::KgpgKeyTrust",
        "QColor",
        "slotChangeHome",
        "slotAddKeyServer",
        "slotChangeEncryptTo",
        "slotDelKeyServer",
        "slotEditKeyServer",
        "QModelIndex",
        "index",
        "slotChangeKeyServerButtonEnable",
        "slotDefaultKeyServer",
        "updateWidgets",
        "updateWidgetsDefault",
        "updateSettings",
        "listKeys",
        "slotInstallDecrypt",
        "mimetype",
        "slotInstallSign",
        "slotRemoveMenu",
        "menu",
        "slotSystrayEnable"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'updateDisplay'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'settingsUpdated'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'changeFont'
        QtMocHelpers::SignalData<void(QFont)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'homeChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'refreshTrust'
        QtMocHelpers::SignalData<void(KgpgCore::KgpgKeyTrust, QColor)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 }, { 0x80000000 | 9, 2 },
        }}),
        // Slot 'slotChangeHome'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAddKeyServer'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotChangeEncryptTo'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDelKeyServer'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEditKeyServer'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEditKeyServer'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'slotChangeKeyServerButtonEnable'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDefaultKeyServer'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateWidgets'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateWidgetsDefault'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateSettings'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'listKeys'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotInstallDecrypt'
        QtMocHelpers::SlotData<void(const QString &)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 24 },
        }}),
        // Slot 'slotInstallSign'
        QtMocHelpers::SlotData<void(const QString &)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 24 },
        }}),
        // Slot 'slotRemoveMenu'
        QtMocHelpers::SlotData<void(const QString &)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 27 },
        }}),
        // Slot 'slotSystrayEnable'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<kgpgOptions, qt_meta_tag_ZN11kgpgOptionsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject kgpgOptions::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11kgpgOptionsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11kgpgOptionsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11kgpgOptionsE_t>.metaTypes,
    nullptr
} };

void kgpgOptions::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<kgpgOptions *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->updateDisplay(); break;
        case 1: _t->settingsUpdated(); break;
        case 2: _t->changeFont((*reinterpret_cast<std::add_pointer_t<QFont>>(_a[1]))); break;
        case 3: _t->homeChanged(); break;
        case 4: _t->refreshTrust((*reinterpret_cast<std::add_pointer_t<KgpgCore::KgpgKeyTrust>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2]))); break;
        case 5: _t->slotChangeHome(); break;
        case 6: _t->slotAddKeyServer(); break;
        case 7: _t->slotChangeEncryptTo(); break;
        case 8: _t->slotDelKeyServer(); break;
        case 9: _t->slotEditKeyServer(); break;
        case 10: _t->slotEditKeyServer((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 11: _t->slotChangeKeyServerButtonEnable(); break;
        case 12: _t->slotDefaultKeyServer(); break;
        case 13: _t->updateWidgets(); break;
        case 14: _t->updateWidgetsDefault(); break;
        case 15: _t->updateSettings(); break;
        case 16: _t->listKeys(); break;
        case 17: _t->slotInstallDecrypt((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 18: _t->slotInstallSign((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: _t->slotRemoveMenu((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 20: _t->slotSystrayEnable(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (kgpgOptions::*)()>(_a, &kgpgOptions::updateDisplay, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (kgpgOptions::*)()>(_a, &kgpgOptions::settingsUpdated, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (kgpgOptions::*)(QFont )>(_a, &kgpgOptions::changeFont, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (kgpgOptions::*)()>(_a, &kgpgOptions::homeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (kgpgOptions::*)(KgpgCore::KgpgKeyTrust , QColor )>(_a, &kgpgOptions::refreshTrust, 4))
            return;
    }
}

const QMetaObject *kgpgOptions::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *kgpgOptions::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11kgpgOptionsE_t>.strings))
        return static_cast<void*>(this);
    return KConfigDialog::qt_metacast(_clname);
}

int kgpgOptions::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 21;
    }
    return _id;
}

// SIGNAL 0
void kgpgOptions::updateDisplay()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void kgpgOptions::settingsUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void kgpgOptions::changeFont(QFont _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void kgpgOptions::homeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void kgpgOptions::refreshTrust(KgpgCore::KgpgKeyTrust _t1, QColor _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}
QT_WARNING_POP
