/********************************************************************************
** Form generated from reading UI file 'conf_gpg.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONF_GPG_H
#define UI_CONF_GPG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_GPGConf
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *groupBox2;
    QHBoxLayout *hboxLayout;
    QVBoxLayout *vboxLayout1;
    QLabel *textLabel1_5_2;
    QLabel *textLabel1_5_2_2;
    QGridLayout *gridLayout;
    QLineEdit *gpg_home_path;
    QSpacerItem *spacerItem;
    QLineEdit *gpg_conf_path;
    QPushButton *changeHome;
    QGroupBox *groupBox3;
    QHBoxLayout *hboxLayout1;
    QLabel *textLabel1_6_2;
    QGridLayout *gridLayout1;
    QLineEdit *kcfg_GpgBinaryPath;
    QSpacerItem *spacerItem1;
    QCheckBox *use_agent;
    QSpacerItem *spacerItem2;

    void setupUi(QWidget *GPGConf)
    {
        if (GPGConf->objectName().isEmpty())
            GPGConf->setObjectName("GPGConf");
        GPGConf->resize(592, 343);
        vboxLayout = new QVBoxLayout(GPGConf);
        vboxLayout->setObjectName("vboxLayout");
        groupBox2 = new QGroupBox(GPGConf);
        groupBox2->setObjectName("groupBox2");
        hboxLayout = new QHBoxLayout(groupBox2);
        hboxLayout->setObjectName("hboxLayout");
        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setObjectName("vboxLayout1");
        textLabel1_5_2 = new QLabel(groupBox2);
        textLabel1_5_2->setObjectName("textLabel1_5_2");
        textLabel1_5_2->setWordWrap(false);

        vboxLayout1->addWidget(textLabel1_5_2);

        textLabel1_5_2_2 = new QLabel(groupBox2);
        textLabel1_5_2_2->setObjectName("textLabel1_5_2_2");
        textLabel1_5_2_2->setWordWrap(false);

        vboxLayout1->addWidget(textLabel1_5_2_2);


        hboxLayout->addLayout(vboxLayout1);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        gpg_home_path = new QLineEdit(groupBox2);
        gpg_home_path->setObjectName("gpg_home_path");
        gpg_home_path->setEnabled(true);
        gpg_home_path->setReadOnly(true);

        gridLayout->addWidget(gpg_home_path, 0, 0, 1, 1);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem, 1, 1, 1, 2);

        gpg_conf_path = new QLineEdit(groupBox2);
        gpg_conf_path->setObjectName("gpg_conf_path");
        gpg_conf_path->setEnabled(true);
        gpg_conf_path->setReadOnly(true);

        gridLayout->addWidget(gpg_conf_path, 1, 0, 1, 1);

        changeHome = new QPushButton(groupBox2);
        changeHome->setObjectName("changeHome");

        gridLayout->addWidget(changeHome, 0, 1, 1, 2);


        hboxLayout->addLayout(gridLayout);


        vboxLayout->addWidget(groupBox2);

        groupBox3 = new QGroupBox(GPGConf);
        groupBox3->setObjectName("groupBox3");
        hboxLayout1 = new QHBoxLayout(groupBox3);
        hboxLayout1->setObjectName("hboxLayout1");
        textLabel1_6_2 = new QLabel(groupBox3);
        textLabel1_6_2->setObjectName("textLabel1_6_2");
        textLabel1_6_2->setWordWrap(false);

        hboxLayout1->addWidget(textLabel1_6_2);

        gridLayout1 = new QGridLayout();
        gridLayout1->setObjectName("gridLayout1");
        kcfg_GpgBinaryPath = new QLineEdit(groupBox3);
        kcfg_GpgBinaryPath->setObjectName("kcfg_GpgBinaryPath");
        kcfg_GpgBinaryPath->setEnabled(true);

        gridLayout1->addWidget(kcfg_GpgBinaryPath, 0, 0, 1, 1);

        spacerItem1 = new QSpacerItem(40, 20, QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacerItem1, 0, 1, 1, 2);


        hboxLayout1->addLayout(gridLayout1);


        vboxLayout->addWidget(groupBox3);

        use_agent = new QCheckBox(GPGConf);
        use_agent->setObjectName("use_agent");

        vboxLayout->addWidget(use_agent);

        spacerItem2 = new QSpacerItem(569, 181, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem2);


        retranslateUi(GPGConf);

        QMetaObject::connectSlotsByName(GPGConf);
    } // setupUi

    void retranslateUi(QWidget *GPGConf)
    {
#if QT_CONFIG(whatsthis)
        GPGConf->setWhatsThis(tr2i18n("<qt><b>Global Settings:</b><br />\n"
"<p></p>\n"
"</qt>", nullptr));
#endif // QT_CONFIG(whatsthis)
        groupBox2->setTitle(tr2i18n("GnuPG Home", nullptr));
#if QT_CONFIG(whatsthis)
        textLabel1_5_2->setWhatsThis(tr2i18n("<b>Home Location</b><p>This is the directory where GnuPG stores its configuration and the keyrings. If you have not changed it this is usually <em>~/.gnupg/</em></p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabel1_5_2->setText(tr2i18n("Home location:", nullptr));
#if QT_CONFIG(whatsthis)
        textLabel1_5_2_2->setWhatsThis(tr2i18n("<b>Configuration File</b><p>This is the name of the configuration file in the directory specified above. The default is <em>gnupg.conf</em> while older versions of GnuPG used <em>options</em>.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabel1_5_2_2->setText(tr2i18n("Configuration file:", nullptr));
        changeHome->setText(tr2i18n("Change...", nullptr));
        groupBox3->setTitle(tr2i18n("GnuPG Binary", nullptr));
#if QT_CONFIG(whatsthis)
        textLabel1_6_2->setWhatsThis(tr2i18n("<b>Program path</b><p>This is the program that will be called for all GnuPG operations. The default of <em>gpg</em> will work on most systems.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabel1_6_2->setText(tr2i18n("Program path:", nullptr));
#if QT_CONFIG(whatsthis)
        use_agent->setWhatsThis(tr2i18n("<b>Use GnuPG agent</b><p>The GnuPG agent stores the passwords for your secret keys in memory for a limited amount of time. If you use your secret key again while it is cached you do not have to enter it again. This is less secure than typing it every time.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        use_agent->setText(tr2i18n("Use GnuPG agent", nullptr));
    } // retranslateUi

};

namespace Ui {
    class GPGConf: public Ui_GPGConf {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONF_GPG_H

