/********************************************************************************
** Form generated from reading UI file 'sourceselect.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SOURCESELECT_H
#define UI_SOURCESELECT_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KUrlRequester"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_SrcSelect
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *buttonGroup2;
    QVBoxLayout *vboxLayout1;
    QRadioButton *checkClipboard;
    QHBoxLayout *hboxLayout;
    QRadioButton *checkFile;
    KUrlRequester *newFilename;
    QHBoxLayout *hboxLayout1;
    QRadioButton *checkServer;
    QLineEdit *keyIds;
    QSpacerItem *spacerItem;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *SrcSelect)
    {
        if (SrcSelect->objectName().isEmpty())
            SrcSelect->setObjectName("SrcSelect");
        SrcSelect->resize(380, 243);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(SrcSelect->sizePolicy().hasHeightForWidth());
        SrcSelect->setSizePolicy(sizePolicy);
        SrcSelect->setMinimumSize(QSize(350, 0));
        vboxLayout = new QVBoxLayout(SrcSelect);
        vboxLayout->setObjectName("vboxLayout");
        buttonGroup2 = new QGroupBox(SrcSelect);
        buttonGroup2->setObjectName("buttonGroup2");
        vboxLayout1 = new QVBoxLayout(buttonGroup2);
        vboxLayout1->setObjectName("vboxLayout1");
        checkClipboard = new QRadioButton(buttonGroup2);
        checkClipboard->setObjectName("checkClipboard");

        vboxLayout1->addWidget(checkClipboard);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        checkFile = new QRadioButton(buttonGroup2);
        checkFile->setObjectName("checkFile");
        checkFile->setChecked(true);

        hboxLayout->addWidget(checkFile);

        newFilename = new KUrlRequester(buttonGroup2);
        newFilename->setObjectName("newFilename");
        newFilename->setEnabled(true);
        newFilename->setMode(KFile::ExistingOnly);

        hboxLayout->addWidget(newFilename);


        vboxLayout1->addLayout(hboxLayout);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        checkServer = new QRadioButton(buttonGroup2);
        checkServer->setObjectName("checkServer");
        checkServer->setChecked(false);

        hboxLayout1->addWidget(checkServer);

        keyIds = new QLineEdit(buttonGroup2);
        keyIds->setObjectName("keyIds");
        keyIds->setEnabled(false);

        hboxLayout1->addWidget(keyIds);


        vboxLayout1->addLayout(hboxLayout1);


        vboxLayout->addWidget(buttonGroup2);

        spacerItem = new QSpacerItem(331, 51, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        vboxLayout->addItem(spacerItem);

        buttonBox = new QDialogButtonBox(SrcSelect);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        vboxLayout->addWidget(buttonBox);


        retranslateUi(SrcSelect);

        QMetaObject::connectSlotsByName(SrcSelect);
    } // setupUi

    void retranslateUi(QWidget *SrcSelect)
    {
        buttonGroup2->setTitle(QString());
        checkClipboard->setText(tr2i18n("C&lipboard", nullptr));
        checkFile->setText(tr2i18n("File:", nullptr));
        checkServer->setText(tr2i18n("&Keyserver:", nullptr));
#if QT_CONFIG(tooltip)
        keyIds->setToolTip(tr2i18n("Enter the ids or fingerprints of the keys to import as space separated list.", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)SrcSelect;
    } // retranslateUi

};

namespace Ui {
    class SrcSelect: public Ui_SrcSelect {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SOURCESELECT_H

