/****************************************************************************
** Meta object code from reading C++ file 'kgpgitemmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../kgpg-26.07.80/model/kgpgitemmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kgpgitemmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13KGpgItemModelE_t {};
} // unnamed namespace

template <> constexpr inline auto KGpgItemModel::qt_create_metaobjectdata<qt_meta_tag_ZN13KGpgItemModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KGpgItemModel",
        "addGroup",
        "KGpgGroupNode*",
        "",
        "name",
        "KGpgKeyNode::List",
        "keys",
        "delNode",
        "KGpgNode*",
        "node",
        "changeGroup",
        "KGpgNode::List",
        "deleteFromGroup",
        "group",
        "KGpgGroupMemberNode*",
        "member",
        "setDefaultKey",
        "KGpgKeyNode*",
        "def",
        "nodeIndex",
        "QModelIndex",
        "column",
        "refreshKey",
        "id",
        "nd",
        "refreshKeys",
        "ids",
        "refreshAllKeys",
        "refreshGroups",
        "invalidateIndexes",
        "refreshTrust",
        "KgpgCore::KgpgKeyTrust",
        "trust",
        "QColor",
        "color"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'addGroup'
        QtMocHelpers::SlotData<KGpgGroupNode *(const QString &, const KGpgKeyNode::List &)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Slot 'delNode'
        QtMocHelpers::SlotData<void(KGpgNode *)>(7, 3, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'changeGroup'
        QtMocHelpers::SlotData<void(KGpgGroupNode *, const KGpgNode::List &)>(10, 3, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 2, 9 }, { 0x80000000 | 11, 6 },
        }}),
        // Slot 'deleteFromGroup'
        QtMocHelpers::SlotData<void(KGpgGroupNode *, KGpgGroupMemberNode *)>(12, 3, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 2, 13 }, { 0x80000000 | 14, 15 },
        }}),
        // Slot 'setDefaultKey'
        QtMocHelpers::SlotData<void(KGpgKeyNode *)>(16, 3, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'nodeIndex'
        QtMocHelpers::SlotData<QModelIndex(KGpgNode *, const int)>(19, 3, QMC::AccessPublic, 0x80000000 | 20, {{
            { 0x80000000 | 8, 9 }, { QMetaType::Int, 21 },
        }}),
        // Slot 'nodeIndex'
        QtMocHelpers::SlotData<QModelIndex(KGpgNode *)>(19, 3, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 20, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'refreshKey'
        QtMocHelpers::SlotData<void(const QString &)>(22, 3, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 23 },
        }}),
        // Slot 'refreshKey'
        QtMocHelpers::SlotData<void(KGpgKeyNode *)>(22, 3, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 24 },
        }}),
        // Slot 'refreshKeys'
        QtMocHelpers::SlotData<void(const QStringList &)>(25, 3, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 26 },
        }}),
        // Slot 'refreshKeys'
        QtMocHelpers::SlotData<void(KGpgKeyNode::List)>(25, 3, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'refreshAllKeys'
        QtMocHelpers::SlotData<void()>(27, 3, QMC::AccessPublic, QMetaType::Void),
        // Slot 'refreshGroups'
        QtMocHelpers::SlotData<void()>(28, 3, QMC::AccessPublic, QMetaType::Void),
        // Slot 'invalidateIndexes'
        QtMocHelpers::SlotData<void(KGpgNode *)>(29, 3, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 24 },
        }}),
        // Slot 'refreshTrust'
        QtMocHelpers::SlotData<void(const KgpgCore::KgpgKeyTrust, const QColor &)>(30, 3, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 31, 32 }, { 0x80000000 | 33, 34 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KGpgItemModel, qt_meta_tag_ZN13KGpgItemModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KGpgItemModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractItemModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KGpgItemModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KGpgItemModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KGpgItemModelE_t>.metaTypes,
    nullptr
} };

void KGpgItemModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KGpgItemModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { KGpgGroupNode* _r = _t->addGroup((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KGpgKeyNode::List>>(_a[2])));
            if (_a[0]) *reinterpret_cast<KGpgGroupNode**>(_a[0]) = std::move(_r); }  break;
        case 1: _t->delNode((*reinterpret_cast<std::add_pointer_t<KGpgNode*>>(_a[1]))); break;
        case 2: _t->changeGroup((*reinterpret_cast<std::add_pointer_t<KGpgGroupNode*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KGpgNode::List>>(_a[2]))); break;
        case 3: _t->deleteFromGroup((*reinterpret_cast<std::add_pointer_t<KGpgGroupNode*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KGpgGroupMemberNode*>>(_a[2]))); break;
        case 4: _t->setDefaultKey((*reinterpret_cast<std::add_pointer_t<KGpgKeyNode*>>(_a[1]))); break;
        case 5: { QModelIndex _r = _t->nodeIndex((*reinterpret_cast<std::add_pointer_t<KGpgNode*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QModelIndex*>(_a[0]) = std::move(_r); }  break;
        case 6: { QModelIndex _r = _t->nodeIndex((*reinterpret_cast<std::add_pointer_t<KGpgNode*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QModelIndex*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->refreshKey((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->refreshKey((*reinterpret_cast<std::add_pointer_t<KGpgKeyNode*>>(_a[1]))); break;
        case 9: _t->refreshKeys((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 10: _t->refreshKeys((*reinterpret_cast<std::add_pointer_t<KGpgKeyNode::List>>(_a[1]))); break;
        case 11: _t->refreshAllKeys(); break;
        case 12: _t->refreshGroups(); break;
        case 13: _t->invalidateIndexes((*reinterpret_cast<std::add_pointer_t<KGpgNode*>>(_a[1]))); break;
        case 14: _t->refreshTrust((*reinterpret_cast<std::add_pointer_t<KgpgCore::KgpgKeyTrust>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KGpgNode* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KGpgKeyNode* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KGpgNode* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KGpgNode* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KGpgKeyNode* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KGpgNode* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *KGpgItemModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KGpgItemModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KGpgItemModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractItemModel::qt_metacast(_clname);
}

int KGpgItemModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}
QT_WARNING_POP
