/****************************************************************************
** Meta object code from reading C++ file 'keysmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../kgpg-26.07.80/keysmanager.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#include <QtCore/QSet>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'keysmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11KeysManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto KeysManager::qt_create_metaobjectdata<qt_meta_tag_ZN11KeysManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KeysManager",
        "readAgainOptions",
        "",
        "certificate",
        "closeAsked",
        "fontChanged",
        "QFont",
        "slotGenerateKey",
        "refreshkey",
        "readAllOptions",
        "showKeyInfo",
        "keyID",
        "slotSetDefaultKey",
        "newID",
        "showKeyManager",
        "importRemoteKey",
        "keyIDs",
        "importRemoteKeys",
        "dialog",
        "showKeyServer",
        "showOptions",
        "slotOpenEditor",
        "slotImport",
        "text",
        "QList<QUrl>",
        "files",
        "clipEncrypt",
        "clipDecrypt",
        "clipSign",
        "slotImportDone",
        "ret",
        "slotGenerateKeyDone",
        "KJob*",
        "job",
        "slotShowTrust",
        "slotShowSize",
        "slotShowCreation",
        "slotShowExpiration",
        "slotAddUidFin",
        "res",
        "slotDelPhotoFinished",
        "quitApp",
        "slotShowLongId",
        "slotSetTrustFilter",
        "slotGotoDefaultKey",
        "slotDelUid",
        "slotDelUidDone",
        "slotPrimUid",
        "slotPrimUidDone",
        "result",
        "slotAddUid",
        "slotAddUidEnable",
        "name",
        "slotUpdatePhoto",
        "slotDeletePhoto",
        "slotAddPhoto",
        "slotAddPhotoFinished",
        "slotSetPhotoSize",
        "size",
        "slotShowPhoto",
        "revokeWidget",
        "slotRevokeDialogFinished",
        "slotRevokeGenerated",
        "doPrint",
        "txt",
        "checkList",
        "slotManpage",
        "slotExportFinished",
        "slotProcessExportMail",
        "slotProcessExportClip",
        "readOptions",
        "slotSetDefKey",
        "confirmdeletekey",
        "deleteseckey",
        "signkey",
        "signuid",
        "caff",
        "slotCaffDone",
        "delsignkey",
        "preimportsignkey",
        "importallsignkey",
        "signatureResult",
        "success",
        "delsignatureResult",
        "defaultAction",
        "QModelIndex",
        "KGpgNode*",
        "slotDefaultAction",
        "showProperties",
        "keyproperties",
        "slotexport",
        "slotexportsec",
        "slotExportSecFinished",
        "slotMenu",
        "QPoint",
        "slotPreImportKey",
        "slotSendEmail",
        "slotedit",
        "addToKAB",
        "slotAddressbookSearchResult",
        "editGroup",
        "createNewGroup",
        "deleteGroup",
        "renameGroup",
        "slotImportRevokeTxt",
        "revokeText",
        "refreshKeyFromServer",
        "slotKeyRefreshDone",
        "slotregenerate",
        "secretKeyDeleted",
        "getMissingSigs",
        "QSet<QString>&",
        "missingKeys",
        "const KGpgExpandableNode*",
        "nd",
        "slotEditDone",
        "exitcode",
        "importRemoteFinished",
        "slotDelKeyDone",
        "slotSetClip",
        "slotOpenKeyUrl"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'readAgainOptions'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'certificate'
        QtMocHelpers::SignalData<void(QString)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'closeAsked'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fontChanged'
        QtMocHelpers::SignalData<void(QFont)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Slot 'slotGenerateKey'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'refreshkey'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'readAllOptions'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showKeyInfo'
        QtMocHelpers::SlotData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Slot 'slotSetDefaultKey'
        QtMocHelpers::SlotData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'showKeyManager'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'importRemoteKey'
        QtMocHelpers::SlotData<bool(const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 16 },
        }}),
        // Slot 'importRemoteKeys'
        QtMocHelpers::SlotData<bool(const QStringList &, const bool)>(17, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QStringList, 16 }, { QMetaType::Bool, 18 },
        }}),
        // Slot 'importRemoteKeys'
        QtMocHelpers::SlotData<bool(const QStringList &)>(17, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::QStringList, 16 },
        }}),
        // Slot 'showKeyServer'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showOptions'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotOpenEditor'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotImport'
        QtMocHelpers::SlotData<void(const QString &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 23 },
        }}),
        // Slot 'slotImport'
        QtMocHelpers::SlotData<void(const QList<QUrl> &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Slot 'clipEncrypt'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clipDecrypt'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clipSign'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotImportDone'
        QtMocHelpers::SlotData<void(int)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 30 },
        }}),
        // Slot 'slotGenerateKeyDone'
        QtMocHelpers::SlotData<void(KJob *)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 32, 33 },
        }}),
        // Slot 'slotShowTrust'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotShowSize'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotShowCreation'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotShowExpiration'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAddUidFin'
        QtMocHelpers::SlotData<void(int)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 39 },
        }}),
        // Slot 'slotDelPhotoFinished'
        QtMocHelpers::SlotData<void(int)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 39 },
        }}),
        // Slot 'quitApp'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotShowLongId'
        QtMocHelpers::SlotData<void(bool)>(42, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotSetTrustFilter'
        QtMocHelpers::SlotData<void(int)>(43, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotGotoDefaultKey'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDelUid'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDelUidDone'
        QtMocHelpers::SlotData<void(int)>(46, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotPrimUid'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotPrimUidDone'
        QtMocHelpers::SlotData<void(int)>(48, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 49 },
        }}),
        // Slot 'slotAddUid'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAddUidEnable'
        QtMocHelpers::SlotData<void(const QString &)>(51, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 52 },
        }}),
        // Slot 'slotUpdatePhoto'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDeletePhoto'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAddPhoto'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAddPhotoFinished'
        QtMocHelpers::SlotData<void(int)>(56, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 39 },
        }}),
        // Slot 'slotSetPhotoSize'
        QtMocHelpers::SlotData<void(int)>(57, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 58 },
        }}),
        // Slot 'slotShowPhoto'
        QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'revokeWidget'
        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRevokeDialogFinished'
        QtMocHelpers::SlotData<void(int)>(61, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 49 },
        }}),
        // Slot 'slotRevokeGenerated'
        QtMocHelpers::SlotData<void(int)>(62, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 49 },
        }}),
        // Slot 'doPrint'
        QtMocHelpers::SlotData<void(const QString &)>(63, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 64 },
        }}),
        // Slot 'checkList'
        QtMocHelpers::SlotData<void()>(65, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotManpage'
        QtMocHelpers::SlotData<void()>(66, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotExportFinished'
        QtMocHelpers::SlotData<void(int)>(67, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 49 },
        }}),
        // Slot 'slotProcessExportMail'
        QtMocHelpers::SlotData<void(int)>(68, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 49 },
        }}),
        // Slot 'slotProcessExportClip'
        QtMocHelpers::SlotData<void(int)>(69, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 49 },
        }}),
        // Slot 'readOptions'
        QtMocHelpers::SlotData<void()>(70, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSetDefKey'
        QtMocHelpers::SlotData<void()>(71, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'confirmdeletekey'
        QtMocHelpers::SlotData<void()>(72, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'deleteseckey'
        QtMocHelpers::SlotData<void()>(73, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'signkey'
        QtMocHelpers::SlotData<void()>(74, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'signuid'
        QtMocHelpers::SlotData<void()>(75, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'caff'
        QtMocHelpers::SlotData<void()>(76, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCaffDone'
        QtMocHelpers::SlotData<void()>(77, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'delsignkey'
        QtMocHelpers::SlotData<void()>(78, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'preimportsignkey'
        QtMocHelpers::SlotData<void()>(79, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'importallsignkey'
        QtMocHelpers::SlotData<void()>(80, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'signatureResult'
        QtMocHelpers::SlotData<void(int)>(81, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 82 },
        }}),
        // Slot 'delsignatureResult'
        QtMocHelpers::SlotData<void(int)>(83, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 82 },
        }}),
        // Slot 'defaultAction'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(84, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 85, 2 },
        }}),
        // Slot 'defaultAction'
        QtMocHelpers::SlotData<void(KGpgNode *)>(84, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 86, 2 },
        }}),
        // Slot 'slotDefaultAction'
        QtMocHelpers::SlotData<void()>(87, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showProperties'
        QtMocHelpers::SlotData<void(KGpgNode *)>(88, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 86, 2 },
        }}),
        // Slot 'keyproperties'
        QtMocHelpers::SlotData<void()>(89, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotexport'
        QtMocHelpers::SlotData<void()>(90, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotexportsec'
        QtMocHelpers::SlotData<void()>(91, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotExportSecFinished'
        QtMocHelpers::SlotData<void(int)>(92, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 49 },
        }}),
        // Slot 'slotMenu'
        QtMocHelpers::SlotData<void(const QPoint &)>(93, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 94, 2 },
        }}),
        // Slot 'slotPreImportKey'
        QtMocHelpers::SlotData<void()>(95, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSendEmail'
        QtMocHelpers::SlotData<void()>(96, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotedit'
        QtMocHelpers::SlotData<void()>(97, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addToKAB'
        QtMocHelpers::SlotData<void()>(98, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAddressbookSearchResult'
        QtMocHelpers::SlotData<void(KJob *)>(99, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 32, 33 },
        }}),
        // Slot 'editGroup'
        QtMocHelpers::SlotData<void()>(100, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'createNewGroup'
        QtMocHelpers::SlotData<void()>(101, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'deleteGroup'
        QtMocHelpers::SlotData<void()>(102, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'renameGroup'
        QtMocHelpers::SlotData<void()>(103, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotImportRevokeTxt'
        QtMocHelpers::SlotData<void(const QString &)>(104, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 105 },
        }}),
        // Slot 'refreshKeyFromServer'
        QtMocHelpers::SlotData<void()>(106, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotKeyRefreshDone'
        QtMocHelpers::SlotData<void(int)>(107, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 49 },
        }}),
        // Slot 'slotregenerate'
        QtMocHelpers::SlotData<void()>(108, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'secretKeyDeleted'
        QtMocHelpers::SlotData<void(int)>(109, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'getMissingSigs'
        QtMocHelpers::SlotData<void(QSet<QString> &, const KGpgExpandableNode *)>(110, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 111, 112 }, { 0x80000000 | 113, 114 },
        }}),
        // Slot 'slotEditDone'
        QtMocHelpers::SlotData<void(int)>(115, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 116 },
        }}),
        // Slot 'importRemoteFinished'
        QtMocHelpers::SlotData<void(int)>(117, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 49 },
        }}),
        // Slot 'slotDelKeyDone'
        QtMocHelpers::SlotData<void(int)>(118, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 30 },
        }}),
        // Slot 'slotSetClip'
        QtMocHelpers::SlotData<void(int)>(119, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 49 },
        }}),
        // Slot 'slotOpenKeyUrl'
        QtMocHelpers::SlotData<void()>(120, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KeysManager, qt_meta_tag_ZN11KeysManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KeysManager::staticMetaObject = { {
    QMetaObject::SuperData::link<KXmlGuiWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KeysManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KeysManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11KeysManagerE_t>.metaTypes,
    nullptr
} };

void KeysManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KeysManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->readAgainOptions(); break;
        case 1: _t->certificate((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->closeAsked(); break;
        case 3: _t->fontChanged((*reinterpret_cast<std::add_pointer_t<QFont>>(_a[1]))); break;
        case 4: _t->slotGenerateKey(); break;
        case 5: _t->refreshkey(); break;
        case 6: _t->readAllOptions(); break;
        case 7: _t->showKeyInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->slotSetDefaultKey((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->showKeyManager(); break;
        case 10: { bool _r = _t->importRemoteKey((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { bool _r = _t->importRemoteKeys((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->importRemoteKeys((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->showKeyServer(); break;
        case 14: _t->showOptions(); break;
        case 15: _t->slotOpenEditor(); break;
        case 16: _t->slotImport((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->slotImport((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 18: _t->clipEncrypt(); break;
        case 19: _t->clipDecrypt(); break;
        case 20: _t->clipSign(); break;
        case 21: _t->slotImportDone((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 22: _t->slotGenerateKeyDone((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 23: _t->slotShowTrust(); break;
        case 24: _t->slotShowSize(); break;
        case 25: _t->slotShowCreation(); break;
        case 26: _t->slotShowExpiration(); break;
        case 27: _t->slotAddUidFin((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 28: _t->slotDelPhotoFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 29: _t->quitApp(); break;
        case 30: _t->slotShowLongId((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 31: _t->slotSetTrustFilter((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 32: _t->slotGotoDefaultKey(); break;
        case 33: _t->slotDelUid(); break;
        case 34: _t->slotDelUidDone((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 35: _t->slotPrimUid(); break;
        case 36: _t->slotPrimUidDone((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 37: _t->slotAddUid(); break;
        case 38: _t->slotAddUidEnable((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 39: _t->slotUpdatePhoto(); break;
        case 40: _t->slotDeletePhoto(); break;
        case 41: _t->slotAddPhoto(); break;
        case 42: _t->slotAddPhotoFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 43: _t->slotSetPhotoSize((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 44: _t->slotShowPhoto(); break;
        case 45: _t->revokeWidget(); break;
        case 46: _t->slotRevokeDialogFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 47: _t->slotRevokeGenerated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 48: _t->doPrint((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 49: _t->checkList(); break;
        case 50: _t->slotManpage(); break;
        case 51: _t->slotExportFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 52: _t->slotProcessExportMail((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 53: _t->slotProcessExportClip((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 54: _t->readOptions(); break;
        case 55: _t->slotSetDefKey(); break;
        case 56: _t->confirmdeletekey(); break;
        case 57: _t->deleteseckey(); break;
        case 58: _t->signkey(); break;
        case 59: _t->signuid(); break;
        case 60: _t->caff(); break;
        case 61: _t->slotCaffDone(); break;
        case 62: _t->delsignkey(); break;
        case 63: _t->preimportsignkey(); break;
        case 64: _t->importallsignkey(); break;
        case 65: _t->signatureResult((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 66: _t->delsignatureResult((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 67: _t->defaultAction((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 68: _t->defaultAction((*reinterpret_cast<std::add_pointer_t<KGpgNode*>>(_a[1]))); break;
        case 69: _t->slotDefaultAction(); break;
        case 70: _t->showProperties((*reinterpret_cast<std::add_pointer_t<KGpgNode*>>(_a[1]))); break;
        case 71: _t->keyproperties(); break;
        case 72: _t->slotexport(); break;
        case 73: _t->slotexportsec(); break;
        case 74: _t->slotExportSecFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 75: _t->slotMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 76: _t->slotPreImportKey(); break;
        case 77: _t->slotSendEmail(); break;
        case 78: _t->slotedit(); break;
        case 79: _t->addToKAB(); break;
        case 80: _t->slotAddressbookSearchResult((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 81: _t->editGroup(); break;
        case 82: _t->createNewGroup(); break;
        case 83: _t->deleteGroup(); break;
        case 84: _t->renameGroup(); break;
        case 85: _t->slotImportRevokeTxt((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 86: _t->refreshKeyFromServer(); break;
        case 87: _t->slotKeyRefreshDone((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 88: _t->slotregenerate(); break;
        case 89: _t->secretKeyDeleted((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 90: _t->getMissingSigs((*reinterpret_cast<std::add_pointer_t<QSet<QString>&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const KGpgExpandableNode*>>(_a[2]))); break;
        case 91: _t->slotEditDone((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 92: _t->importRemoteFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 93: _t->slotDelKeyDone((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 94: _t->slotSetClip((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 95: _t->slotOpenKeyUrl(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 68:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KGpgNode* >(); break;
            }
            break;
        case 70:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KGpgNode* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KeysManager::*)()>(_a, &KeysManager::readAgainOptions, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeysManager::*)(QString )>(_a, &KeysManager::certificate, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeysManager::*)()>(_a, &KeysManager::closeAsked, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeysManager::*)(QFont )>(_a, &KeysManager::fontChanged, 3))
            return;
    }
}

const QMetaObject *KeysManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KeysManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KeysManagerE_t>.strings))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int KeysManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 96)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 96;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 96)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 96;
    }
    return _id;
}

// SIGNAL 0
void KeysManager::readAgainOptions()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KeysManager::certificate(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KeysManager::closeAsked()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KeysManager::fontChanged(QFont _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
