/********************************************************************************
** Form generated from reading UI file 'keyexport.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KEYEXPORT_H
#define UI_KEYEXPORT_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_KeyExport
{
public:
    QVBoxLayout *vboxLayout;
    QWidget *widget;
    QVBoxLayout *verticalLayout;
    QGroupBox *buttonGroup2;
    QVBoxLayout *vboxLayout1;
    QRadioButton *checkMail;
    QRadioButton *checkClipboard;
    QRadioButton *checkServer;
    QComboBox *destServer;
    QRadioButton *checkFile;
    KUrlRequester *newFilename;
    QGroupBox *buttonGroup3;
    QVBoxLayout *vboxLayout2;
    QRadioButton *checkAttrAll;
    QRadioButton *checkAttrPhoto;
    QRadioButton *checkAttrClean;
    QSpacerItem *spacerItem;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *KeyExport)
    {
        if (KeyExport->objectName().isEmpty())
            KeyExport->setObjectName("KeyExport");
        KeyExport->resize(626, 462);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(KeyExport->sizePolicy().hasHeightForWidth());
        KeyExport->setSizePolicy(sizePolicy);
        KeyExport->setMinimumSize(QSize(350, 0));
        vboxLayout = new QVBoxLayout(KeyExport);
        vboxLayout->setObjectName("vboxLayout");
        widget = new QWidget(KeyExport);
        widget->setObjectName("widget");
        verticalLayout = new QVBoxLayout(widget);
        verticalLayout->setObjectName("verticalLayout");
        buttonGroup2 = new QGroupBox(widget);
        buttonGroup2->setObjectName("buttonGroup2");
        vboxLayout1 = new QVBoxLayout(buttonGroup2);
        vboxLayout1->setObjectName("vboxLayout1");
        checkMail = new QRadioButton(buttonGroup2);
        checkMail->setObjectName("checkMail");

        vboxLayout1->addWidget(checkMail);

        checkClipboard = new QRadioButton(buttonGroup2);
        checkClipboard->setObjectName("checkClipboard");

        vboxLayout1->addWidget(checkClipboard);

        checkServer = new QRadioButton(buttonGroup2);
        checkServer->setObjectName("checkServer");
        checkServer->setEnabled(false);

        vboxLayout1->addWidget(checkServer);

        destServer = new QComboBox(buttonGroup2);
        destServer->setObjectName("destServer");
        destServer->setEnabled(false);

        vboxLayout1->addWidget(destServer);

        checkFile = new QRadioButton(buttonGroup2);
        checkFile->setObjectName("checkFile");
        checkFile->setChecked(true);

        vboxLayout1->addWidget(checkFile);

        newFilename = new KUrlRequester(buttonGroup2);
        newFilename->setObjectName("newFilename");
        newFilename->setEnabled(true);

        vboxLayout1->addWidget(newFilename);


        verticalLayout->addWidget(buttonGroup2);

        buttonGroup3 = new QGroupBox(widget);
        buttonGroup3->setObjectName("buttonGroup3");
        vboxLayout2 = new QVBoxLayout(buttonGroup3);
        vboxLayout2->setObjectName("vboxLayout2");
        checkAttrAll = new QRadioButton(buttonGroup3);
        checkAttrAll->setObjectName("checkAttrAll");
        checkAttrAll->setChecked(true);

        vboxLayout2->addWidget(checkAttrAll);

        checkAttrPhoto = new QRadioButton(buttonGroup3);
        checkAttrPhoto->setObjectName("checkAttrPhoto");

        vboxLayout2->addWidget(checkAttrPhoto);

        checkAttrClean = new QRadioButton(buttonGroup3);
        checkAttrClean->setObjectName("checkAttrClean");

        vboxLayout2->addWidget(checkAttrClean);

        spacerItem = new QSpacerItem(602, 108, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        vboxLayout2->addItem(spacerItem);


        verticalLayout->addWidget(buttonGroup3);

        buttonBox = new QDialogButtonBox(widget);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        vboxLayout->addWidget(widget);


        retranslateUi(KeyExport);

        QMetaObject::connectSlotsByName(KeyExport);
    } // setupUi

    void retranslateUi(QDialog *KeyExport)
    {
        KeyExport->setWindowTitle(tr2i18n("Public Key Export", nullptr));
        buttonGroup2->setTitle(QString());
        checkMail->setText(tr2i18n("E&mail", "Export a key via email"));
        checkClipboard->setText(tr2i18n("C&lipboard", nullptr));
#if QT_CONFIG(tooltip)
        checkServer->setToolTip(tr2i18n("You must define at least one keyserver in settings before you can export to one.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkServer->setText(tr2i18n("&Key server:", nullptr));
        checkFile->setText(tr2i18n("File:", nullptr));
        buttonGroup3->setTitle(tr2i18n("Export Settings", nullptr));
        checkAttrAll->setText(tr2i18n("E&xport everything", nullptr));
        checkAttrPhoto->setText(tr2i18n("Do &not export attributes (photo ids)", nullptr));
        checkAttrClean->setText(tr2i18n("Clean key", "@option:radio Exports the smallest key possible. Maps to export-minimal option of gpg"));
    } // retranslateUi

};

namespace Ui {
    class KeyExport: public Ui_KeyExport {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KEYEXPORT_H

