/********************************************************************************
** Form generated from reading UI file 'conf_decryption.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONF_DECRYPTION_H
#define UI_CONF_DECRYPTION_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_Decryption
{
public:
    QGridLayout *gridLayout;
    QLineEdit *kcfg_CustomDecrypt;
    QSpacerItem *spacerItem;
    QLabel *textLabel1_4_2;

    void setupUi(QWidget *Decryption)
    {
        if (Decryption->objectName().isEmpty())
            Decryption->setObjectName("Decryption");
        Decryption->resize(388, 233);
        gridLayout = new QGridLayout(Decryption);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        kcfg_CustomDecrypt = new QLineEdit(Decryption);
        kcfg_CustomDecrypt->setObjectName("kcfg_CustomDecrypt");
        kcfg_CustomDecrypt->setEnabled(true);

        gridLayout->addWidget(kcfg_CustomDecrypt, 1, 0, 1, 1);

        spacerItem = new QSpacerItem(21, 155, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(spacerItem, 2, 0, 1, 1);

        textLabel1_4_2 = new QLabel(Decryption);
        textLabel1_4_2->setObjectName("textLabel1_4_2");
        textLabel1_4_2->setWordWrap(false);

        gridLayout->addWidget(textLabel1_4_2, 0, 0, 1, 1);


        retranslateUi(Decryption);

        QMetaObject::connectSlotsByName(Decryption);
    } // setupUi

    void retranslateUi(QWidget *Decryption)
    {
#if QT_CONFIG(whatsthis)
        textLabel1_4_2->setWhatsThis(tr2i18n("<qt><b>Custom Decryption Command:</b><br />\n"
"<p>This option allows the user to specify a custom command to be executed by GPG when decryption occurs. (This is recommended for advanced users only).</p></qt>", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabel1_4_2->setText(tr2i18n("Custom decryption command:", nullptr));
        (void)Decryption;
    } // retranslateUi

};

namespace Ui {
    class Decryption: public Ui_Decryption {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONF_DECRYPTION_H

