/********************************************************************************
** Form generated from reading UI file 'kgpgkeygenerate.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KGPGKEYGENERATE_H
#define UI_KGPGKEYGENERATE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_kgpgKeyGenerate
{
public:
    QGroupBox *vgroup;
    QVBoxLayout *verticalLayout;
    QLabel *nameLabel;
    QLineEdit *m_kname;
    QLabel *emailLabel;
    QLineEdit *m_mail;
    QLabel *label_2;
    QLineEdit *m_comment;
    QLabel *label_3;
    QHBoxLayout *horizontalLayout;
    QSpinBox *m_days;
    QComboBox *m_keyexp;
    QLabel *label_4;
    QComboBox *m_keysize;
    QLabel *label_5;
    QComboBox *m_keykind;
    QGroupBox *capabilities;
    QFormLayout *formLayout;
    QCheckBox *capCert;
    QCheckBox *capSign;
    QCheckBox *capAuth;
    QCheckBox *capEncrypt;

    void setupUi(QDialog *kgpgKeyGenerate)
    {
        if (kgpgKeyGenerate->objectName().isEmpty())
            kgpgKeyGenerate->setObjectName("kgpgKeyGenerate");
        kgpgKeyGenerate->resize(367, 464);
        vgroup = new QGroupBox(kgpgKeyGenerate);
        vgroup->setObjectName("vgroup");
        vgroup->setGeometry(QRect(0, 10, 361, 434));
        verticalLayout = new QVBoxLayout(vgroup);
        verticalLayout->setObjectName("verticalLayout");
        nameLabel = new QLabel(vgroup);
        nameLabel->setObjectName("nameLabel");

        verticalLayout->addWidget(nameLabel);

        m_kname = new QLineEdit(vgroup);
        m_kname->setObjectName("m_kname");

        verticalLayout->addWidget(m_kname);

        emailLabel = new QLabel(vgroup);
        emailLabel->setObjectName("emailLabel");

        verticalLayout->addWidget(emailLabel);

        m_mail = new QLineEdit(vgroup);
        m_mail->setObjectName("m_mail");

        verticalLayout->addWidget(m_mail);

        label_2 = new QLabel(vgroup);
        label_2->setObjectName("label_2");

        verticalLayout->addWidget(label_2);

        m_comment = new QLineEdit(vgroup);
        m_comment->setObjectName("m_comment");

        verticalLayout->addWidget(m_comment);

        label_3 = new QLabel(vgroup);
        label_3->setObjectName("label_3");

        verticalLayout->addWidget(label_3);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        m_days = new QSpinBox(vgroup);
        m_days->setObjectName("m_days");
        m_days->setEnabled(false);
        m_days->setMaximum(9999);

        horizontalLayout->addWidget(m_days);

        m_keyexp = new QComboBox(vgroup);
        m_keyexp->addItem(QString());
        m_keyexp->addItem(QString());
        m_keyexp->addItem(QString());
        m_keyexp->addItem(QString());
        m_keyexp->addItem(QString());
        m_keyexp->setObjectName("m_keyexp");

        horizontalLayout->addWidget(m_keyexp);


        verticalLayout->addLayout(horizontalLayout);

        label_4 = new QLabel(vgroup);
        label_4->setObjectName("label_4");

        verticalLayout->addWidget(label_4);

        m_keysize = new QComboBox(vgroup);
        m_keysize->setObjectName("m_keysize");

        verticalLayout->addWidget(m_keysize);

        label_5 = new QLabel(vgroup);
        label_5->setObjectName("label_5");

        verticalLayout->addWidget(label_5);

        m_keykind = new QComboBox(vgroup);
        m_keykind->setObjectName("m_keykind");

        verticalLayout->addWidget(m_keykind);

        capabilities = new QGroupBox(vgroup);
        capabilities->setObjectName("capabilities");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(capabilities->sizePolicy().hasHeightForWidth());
        capabilities->setSizePolicy(sizePolicy);
        formLayout = new QFormLayout(capabilities);
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        capCert = new QCheckBox(capabilities);
        capCert->setObjectName("capCert");
        capCert->setEnabled(false);
        capCert->setChecked(true);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, capCert);

        capSign = new QCheckBox(capabilities);
        capSign->setObjectName("capSign");
        capSign->setChecked(true);

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, capSign);

        capAuth = new QCheckBox(capabilities);
        capAuth->setObjectName("capAuth");
        capAuth->setChecked(true);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, capAuth);

        capEncrypt = new QCheckBox(capabilities);
        capEncrypt->setObjectName("capEncrypt");
        capEncrypt->setChecked(true);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, capEncrypt);


        verticalLayout->addWidget(capabilities);

#if QT_CONFIG(shortcut)
        nameLabel->setBuddy(m_kname);
        emailLabel->setBuddy(m_mail);
        label_2->setBuddy(m_comment);
        label_4->setBuddy(m_keysize);
        label_5->setBuddy(m_keykind);
#endif // QT_CONFIG(shortcut)

        retranslateUi(kgpgKeyGenerate);

        QMetaObject::connectSlotsByName(kgpgKeyGenerate);
    } // setupUi

    void retranslateUi(QDialog *kgpgKeyGenerate)
    {
        kgpgKeyGenerate->setWindowTitle(tr2i18n("Key Generation", nullptr));
        vgroup->setTitle(tr2i18n("Generate Key Pair", nullptr));
        nameLabel->setText(tr2i18n("&Name:", nullptr));
#if QT_CONFIG(tooltip)
        m_kname->setToolTip(tr2i18n("The name must have a length of at least 5 characters and must not begin with a digit.", nullptr));
#endif // QT_CONFIG(tooltip)
        m_kname->setPlaceholderText(tr2i18n("Real name, at least 5 characters, no leading digits", nullptr));
        emailLabel->setText(tr2i18n("E&mail (optional):", nullptr));
        label_2->setText(tr2i18n("Commen&t (optional):", nullptr));
        label_3->setText(tr2i18n("Expiration:", nullptr));
        m_keyexp->setItemText(0, tr2i18n("Never", "Key will not expire"));
        m_keyexp->setItemText(1, tr2i18n("Days", nullptr));
        m_keyexp->setItemText(2, tr2i18n("Weeks", nullptr));
        m_keyexp->setItemText(3, tr2i18n("Months", nullptr));
        m_keyexp->setItemText(4, tr2i18n("Years", nullptr));

        label_4->setText(tr2i18n("&Key size:", nullptr));
        label_5->setText(tr2i18n("&Algorithm:", nullptr));
        capabilities->setTitle(tr2i18n("Capabilities", nullptr));
#if QT_CONFIG(tooltip)
        capCert->setToolTip(tr2i18n("Certification is automatically enabled for all keys", nullptr));
#endif // QT_CONFIG(tooltip)
        capCert->setText(tr2i18n("Certification", nullptr));
        capSign->setText(tr2i18n("Signature", nullptr));
        capAuth->setText(tr2i18n("Authentication", nullptr));
        capEncrypt->setText(tr2i18n("Encryption", nullptr));
    } // retranslateUi

};

namespace Ui {
    class kgpgKeyGenerate: public Ui_kgpgKeyGenerate {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KGPGKEYGENERATE_H

