/********************************************************************************
** Form generated from reading UI file 'groupedit.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GROUPEDIT_H
#define UI_GROUPEDIT_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTableView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_groupEdit
{
public:
    QVBoxLayout *vboxLayout;
    QLabel *textLabelAvailable;
    QHBoxLayout *hboxLayout;
    QLabel *label;
    QLineEdit *filterEdit;
    QTableView *availableKeys;
    QHBoxLayout *hboxLayout1;
    QLabel *kActiveLabel1;
    QPushButton *buttonAdd;
    QPushButton *buttonRemove;
    QSpacerItem *spacerItem;
    QTableView *groupKeys;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *groupEdit)
    {
        if (groupEdit->objectName().isEmpty())
            groupEdit->setObjectName("groupEdit");
        groupEdit->resize(583, 456);
        vboxLayout = new QVBoxLayout(groupEdit);
        vboxLayout->setObjectName("vboxLayout");
        textLabelAvailable = new QLabel(groupEdit);
        textLabelAvailable->setObjectName("textLabelAvailable");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(textLabelAvailable->sizePolicy().hasHeightForWidth());
        textLabelAvailable->setSizePolicy(sizePolicy);
        QFont font;
        font.setBold(true);
        textLabelAvailable->setFont(font);
        textLabelAvailable->setWordWrap(false);

        vboxLayout->addWidget(textLabelAvailable);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        label = new QLabel(groupEdit);
        label->setObjectName("label");

        hboxLayout->addWidget(label);

        filterEdit = new QLineEdit(groupEdit);
        filterEdit->setObjectName("filterEdit");
        filterEdit->setClearButtonEnabled(true);

        hboxLayout->addWidget(filterEdit);


        vboxLayout->addLayout(hboxLayout);

        availableKeys = new QTableView(groupEdit);
        availableKeys->setObjectName("availableKeys");
        availableKeys->setAcceptDrops(true);
        availableKeys->setDragEnabled(false);
        availableKeys->setAlternatingRowColors(true);
        availableKeys->setSelectionMode(QAbstractItemView::ExtendedSelection);
        availableKeys->setSelectionBehavior(QAbstractItemView::SelectRows);
        availableKeys->setSortingEnabled(true);

        vboxLayout->addWidget(availableKeys);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        kActiveLabel1 = new QLabel(groupEdit);
        kActiveLabel1->setObjectName("kActiveLabel1");
        kActiveLabel1->setFont(font);

        hboxLayout1->addWidget(kActiveLabel1);

        buttonAdd = new QPushButton(groupEdit);
        buttonAdd->setObjectName("buttonAdd");

        hboxLayout1->addWidget(buttonAdd);

        buttonRemove = new QPushButton(groupEdit);
        buttonRemove->setObjectName("buttonRemove");

        hboxLayout1->addWidget(buttonRemove);

        spacerItem = new QSpacerItem(71, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem);


        vboxLayout->addLayout(hboxLayout1);

        groupKeys = new QTableView(groupEdit);
        groupKeys->setObjectName("groupKeys");
        groupKeys->setAcceptDrops(true);
        groupKeys->setDragEnabled(false);
        groupKeys->setAlternatingRowColors(true);
        groupKeys->setSelectionMode(QAbstractItemView::ExtendedSelection);
        groupKeys->setSelectionBehavior(QAbstractItemView::SelectRows);
        groupKeys->setSortingEnabled(true);

        vboxLayout->addWidget(groupKeys);

        buttonBox = new QDialogButtonBox(groupEdit);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        vboxLayout->addWidget(buttonBox);


        retranslateUi(groupEdit);

        QMetaObject::connectSlotsByName(groupEdit);
    } // setupUi

    void retranslateUi(QWidget *groupEdit)
    {
        label->setText(tr2i18n("Search:", nullptr));
        kActiveLabel1->setText(tr2i18n("Keys in the Group", nullptr));
        buttonAdd->setText(QString());
        buttonRemove->setText(QString());
        (void)groupEdit;
    } // retranslateUi

};

namespace Ui {
    class groupEdit: public Ui_groupEdit {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GROUPEDIT_H

